aboutsummaryrefslogtreecommitdiff
path: root/examples/GuiClient
diff options
context:
space:
mode:
authorManjeet Dahiya <manjeetdahiya@gmail.com>2010-10-14 11:12:56 +0000
committerManjeet Dahiya <manjeetdahiya@gmail.com>2010-10-14 11:12:56 +0000
commit1ae15dd2d9e2f8360929960267b2a9dda5595ab5 (patch)
tree63ee415df4f71694f8f9e05507ccbe3203357aa5 /examples/GuiClient
parentee6314a8a34a0ad1e11c64ea00b63ce0aea4db5c (diff)
downloadqxmpp-1ae15dd2d9e2f8360929960267b2a9dda5595ab5.tar.gz
change class name
Diffstat (limited to 'examples/GuiClient')
-rw-r--r--examples/GuiClient/GuiClient.pro4
-rw-r--r--examples/GuiClient/mainDialog.cpp6
-rw-r--r--examples/GuiClient/mainDialog.ui6
-rw-r--r--examples/GuiClient/signInStatusLabel.cpp (renamed from examples/GuiClient/customLabel.cpp)10
-rw-r--r--examples/GuiClient/signInStatusLabel.h (renamed from examples/GuiClient/customLabel.h)14
5 files changed, 20 insertions, 20 deletions
diff --git a/examples/GuiClient/GuiClient.pro b/examples/GuiClient/GuiClient.pro
index bb17ac5f..c25c9b1b 100644
--- a/examples/GuiClient/GuiClient.pro
+++ b/examples/GuiClient/GuiClient.pro
@@ -16,7 +16,7 @@ SOURCES += main.cpp \
rosterListView.cpp \
searchLineEdit.cpp \
statusWidget.cpp \
- customLabel.cpp \
+ signInStatusLabel.cpp \
statusAvatarWidget.cpp \
statusTextWidget.cpp \
statusToolButton.cpp \
@@ -38,7 +38,7 @@ HEADERS += chatMsgGraphicsItem.h \
rosterListView.h \
searchLineEdit.h \
statusWidget.h \
- customLabel.h \
+ signInStatusLabel.h \
statusAvatarWidget.h \
statusTextWidget.h \
statusToolButton.h \
diff --git a/examples/GuiClient/mainDialog.cpp b/examples/GuiClient/mainDialog.cpp
index 258af314..2322b13a 100644
--- a/examples/GuiClient/mainDialog.cpp
+++ b/examples/GuiClient/mainDialog.cpp
@@ -541,17 +541,17 @@ void mainDialog::startConnection()
void mainDialog::showLoginStatus(const QString& msg)
{
- ui->label_status->setCustomText(msg, customLabel::None);
+ ui->label_status->setCustomText(msg, signInStatusLabel::None);
}
void mainDialog::showLoginStatusWithProgress(const QString& msg)
{
- ui->label_status->setCustomText(msg, customLabel::WithProgressEllipsis);
+ ui->label_status->setCustomText(msg, signInStatusLabel::WithProgressEllipsis);
}
void mainDialog::showLoginStatusWithCounter(const QString& msg, int time)
{
- ui->label_status->setCustomText(msg, customLabel::CountDown, time);
+ ui->label_status->setCustomText(msg, signInStatusLabel::CountDown, time);
}
void mainDialog::updateVCard(const QString& bareJid)
diff --git a/examples/GuiClient/mainDialog.ui b/examples/GuiClient/mainDialog.ui
index 0d174462..987b5dca 100644
--- a/examples/GuiClient/mainDialog.ui
+++ b/examples/GuiClient/mainDialog.ui
@@ -233,7 +233,7 @@
</spacer>
</item>
<item>
- <widget class="customLabel" name="label_status">
+ <widget class="signInStatusLabel" name="label_status">
<property name="text">
<string/>
</property>
@@ -351,9 +351,9 @@
<header>searchLineEdit.h</header>
</customwidget>
<customwidget>
- <class>customLabel</class>
+ <class>signInStatusLabel</class>
<extends>QLabel</extends>
- <header>customLabel.h</header>
+ <header>signInStatusLabel.h</header>
</customwidget>
</customwidgets>
<resources>
diff --git a/examples/GuiClient/customLabel.h b/examples/GuiClient/signInStatusLabel.h
index 7d4ead81..3eae8686 100644
--- a/examples/GuiClient/customLabel.h
+++ b/examples/GuiClient/signInStatusLabel.h
@@ -22,13 +22,13 @@
*/
-#ifndef CUSTOMLABEL_H
-#define CUSTOMLABEL_H
+#ifndef SIGNINSTATUSLABEL_H
+#define SIGNINSTATUSLABEL_H
#include <QLabel>
#include <QTimer>
-class customLabel : public QLabel
+class signInStatusLabel : public QLabel
{
Q_OBJECT
@@ -39,9 +39,9 @@ public:
WithProgressEllipsis,
CountDown
};
- customLabel(QWidget* parent = 0);
+ signInStatusLabel(QWidget* parent = 0);
- void setCustomText(const QString& text, customLabel::Option op = None,
+ void setCustomText(const QString& text, signInStatusLabel::Option op = None,
int countDown = 0);
// QSize sizeHint() const;
@@ -51,10 +51,10 @@ private slots:
private:
QTimer m_timer;
- customLabel::Option m_option;
+ signInStatusLabel::Option m_option;
QString m_text;
QString m_postfix;
int m_countDown;
};
-#endif // CUSTOMLABEL_H
+#endif // SIGNINSTATUSLABEL_H
diff --git a/examples/GuiClient/customLabel.cpp b/examples/GuiClient/signInStatusLabel.cpp
index ec29d678..bc4437e3 100644
--- a/examples/GuiClient/customLabel.cpp
+++ b/examples/GuiClient/signInStatusLabel.cpp
@@ -22,10 +22,10 @@
*/
-#include "customLabel.h"
+#include "signInStatusLabel.h"
#include <QFontMetrics>
-customLabel::customLabel(QWidget* parent):QLabel(parent), m_timer(this),
+signInStatusLabel::signInStatusLabel(QWidget* parent):QLabel(parent), m_timer(this),
m_option(None)
{
m_timer.setSingleShot(false);
@@ -35,7 +35,7 @@ customLabel::customLabel(QWidget* parent):QLabel(parent), m_timer(this),
Q_UNUSED(check);
}
-void customLabel::setCustomText(const QString& text, customLabel::Option op,
+void signInStatusLabel::setCustomText(const QString& text, signInStatusLabel::Option op,
int countDown)
{
m_text = text;
@@ -69,7 +69,7 @@ void customLabel::setCustomText(const QString& text, customLabel::Option op,
updateGeometry();
}
-void customLabel::timeout()
+void signInStatusLabel::timeout()
{
switch(m_option)
{
@@ -101,7 +101,7 @@ void customLabel::timeout()
updateGeometry();
}
//QSize customLabel::sizeHint() const
//{
// QFont font;
// QFontMetrics fm(font);
@@ -101,7 +101,7 @@ void customLabel::timeout()
updateGeometry();
}
-//QSize customLabel::sizeHint() const
+//QSize signInStatusLabel::sizeHint() const
//{
// QFont font;